BipartiteGameOptions

Struct BipartiteGameOptions 

pub struct BipartiteGameOptions {
    pub directed: bool,
    pub mode: NeighborMode,
    pub allowed_edge_types: EdgeTypeSw,
    pub edge_labeled: bool,
}
Parameters shared by the random bipartite generators Graph::bipartite_game_gnp and Graph::bipartite_game_gnm.

The default is an undirected simple graph from the classic (edge-unlabeled) Erdős–Rényi model.

Fields

directed: bool

Whether to generate a directed graph (default false).

mode: NeighborMode

Direction of the edges in directed graphs (default NeighborMode::Out): Out points from bottom (type false) to top (type true) vertices, In the other way around; with All each edge direction is sampled independently, so mutual edges may appear. Ignored if undirected.

allowed_edge_types: EdgeTypeSw

Allowed edge types (default EdgeTypeSw::Simple): use EdgeTypeSw::Multi to allow multi-edges. Self-loops are never possible in a bipartite graph, so EdgeTypeSw::Loops is the same as EdgeTypeSw::Simple.

edge_labeled: bool

If true, sample uniformly from ordered edge lists (edge-labeled graphs) instead of the classic model (default false). Only relevant when multi-edges are allowed: with simple graphs, Graph::bipartite_game_gnm only shuffles the edge order and Graph::bipartite_game_gnp fails with ErrorKind::Unimplemented.

Implementations

Source

impl BipartiteGameOptions

pub fn with_directed(self, directed: bool, mode: NeighborMode) -> Self

Sets directed and mode.

pub fn with_allowed_edge_types(self, allowed: EdgeTypeSw) -> Self

pub fn with_edge_labeled(self, edge_labeled: bool) -> Self