pub struct BipartiteProjection {
pub proj1: Graph,
pub proj2: Graph,
pub multiplicity1: Vec<i64>,
pub multiplicity2: Vec<i64>,
}Expand description
The two one-mode projections of a bipartite graph, the output of
Graph::bipartite_projection.
Each projection has one vertex per vertex of the corresponding type, numbered in increasing order of the original ids; two vertices are connected if they share at least one neighbor in the other class.
Fields
proj1: GraphThe first projection.
proj2: GraphThe second projection.
multiplicity1: Vec<i64>For each edge of proj1, the number of common neighbors of its
endpoints in the original graph (in a multigraph: the number of
paths of length two between them).
multiplicity2: Vec<i64>For each edge of proj2, the number of common neighbors of its
endpoints in the original graph (in a multigraph: the number of
paths of length two between them).