pub struct WeightedBipartiteGraph {
pub graph: Graph,
pub types: Vec<bool>,
pub weights: Vec<f64>,
}Expand description
A bipartite graph with edge weights, the output of Graph::weighted_biadjacency.
Fields
graph: GraphThe graph.
types: Vec<bool>The type of each vertex, indexed by vertex id.
weights: Vec<f64>The weight of each edge, indexed by edge id.